@@ -287,9 +287,9 @@ class ApiGatewayToIotProps:
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
         '''
         if isinstance(api_gateway_props, dict):
-            api_gateway_props = RestApiProps(**api_gateway_props)
+            api_gateway_props = aws_cdk.aws_apigateway.RestApiProps(**api_gateway_props)
         if isinstance(log_group_props, dict):
-            log_group_props = LogGroupProps(**log_group_props)
+            log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         if __debug__:
             type_hints = typing.get_type_hints(ApiGatewayToIotProps.__init__)
             check_type(argname="argument iot_endpoint", value=iot_endpoint, expected_type=type_hints["iot_endpoint"])
